summaryrefslogtreecommitdiffstats
path: root/ipalib/plugins/netgroup.py
diff options
context:
space:
mode:
Diffstat (limited to 'ipalib/plugins/netgroup.py')
-rw-r--r--ipalib/plugins/netgroup.py13
1 files changed, 9 insertions, 4 deletions
diff --git a/ipalib/plugins/netgroup.py b/ipalib/plugins/netgroup.py
index 56e026ed2..e611ea299 100644
--- a/ipalib/plugins/netgroup.py
+++ b/ipalib/plugins/netgroup.py
@@ -189,18 +189,23 @@ class netgroup_find(LDAPSearch):
takes_options = LDAPSearch.takes_options + (
Flag('private',
- cli_name='private',
- doc=_('search for private groups'),
+ exclude='webui',
+ flags=['no_option', 'no_output'],
+ ),
+ Flag('managed',
+ cli_name='managed',
+ doc=_('search for managed groups'),
+ default_from=lambda private: private,
),
)
def pre_callback(self, ldap, filter, attrs_list, base_dn, scope, *args, **options):
# Do not display private mepManagedEntry netgroups by default
# If looking for private groups, we need to omit the negation search filter
search_kw = {}
search_kw['objectclass'] = ['mepManagedEntry']
- if not options['private']:
+ if not options['managed']:
local_filter = ldap.make_filter(search_kw, rules=ldap.MATCH_NONE)
else:
local_filter = ldap.make_filter(search_kw, rules=ldap.MATCH_ALL)
@@ -189,18 +189,23 @@ class netgroup_find(LDAPSearch):
def pre_callback(self, ldap, filter, attrs_list, base_dn, scope, *args, **options):
# Do not display private mepManagedEntry netgroups by default
- # If looking for private groups, we need to omit the negation search filter
+ # If looking for managed groups, we need to omit the negation search filter
search_kw = {}
search_kw['objectclass'] = ['mepManagedEntry']